Index: src/mark-compact.h |
diff --git a/src/mark-compact.h b/src/mark-compact.h |
index a942600d63041516185a13d2f913ae64b87d7421..4063bde2d30d0f7eafb9c324a7e87194b5d5c2c2 100644 |
--- a/src/mark-compact.h |
+++ b/src/mark-compact.h |
@@ -695,9 +695,11 @@ class MarkCompactCollector { |
bool TryPromoteObject(HeapObject* object, int object_size); |
- inline Object* encountered_weak_maps() { return encountered_weak_maps_; } |
- inline void set_encountered_weak_maps(Object* weak_map) { |
- encountered_weak_maps_ = weak_map; |
+ inline Object* encountered_weak_collections() { |
+ return encountered_weak_collections_; |
+ } |
+ inline void set_encountered_weak_collections(Object* weak_collection) { |
+ encountered_weak_collections_ = weak_collection; |
} |
void InvalidateCode(Code* code); |
@@ -893,15 +895,15 @@ class MarkCompactCollector { |
// ClearNonLiveTransitions pass or by calling this function. |
void ReattachInitialMaps(); |
- // Mark all values associated with reachable keys in weak maps encountered |
- // so far. This might push new object or even new weak maps onto the |
- // marking stack. |
- void ProcessWeakMaps(); |
+ // Mark all values associated with reachable keys in weak collections |
+ // encountered so far. This might push new object or even new weak maps onto |
+ // the marking stack. |
+ void ProcessWeakCollections(); |
// After all reachable objects have been marked those weak map entries |
// with an unreachable key are removed from all encountered weak maps. |
// The linked list of all encountered weak maps is destroyed. |
- void ClearWeakMaps(); |
+ void ClearWeakCollections(); |
// ----------------------------------------------------------------------- |
// Phase 2: Sweeping to clear mark bits and free non-live objects for |
@@ -943,7 +945,7 @@ class MarkCompactCollector { |
Heap* heap_; |
MarkingDeque marking_deque_; |
CodeFlusher* code_flusher_; |
- Object* encountered_weak_maps_; |
+ Object* encountered_weak_collections_; |
List<Page*> evacuation_candidates_; |
List<Code*> invalidated_code_; |